install.packages("tidyverse")
install.packages("ggplot2")
library(tidyverse)
library(ggplot2)
library(dplyr)
library(forcats)

df <- read.csv("/home/mcroiset/HiC/benchmark/recap.txt", sep = "\t", header = TRUE)

convert_time <- function(x){
  parts <- strsplit(x, " ")
  list_durations <- character(0)
  for( part in parts ) {
    sec <- 0
    minute <- 0
    hours <- 0
    mili <- 0
    for ( single in part ) {
      if (grepl('\\d+s', single)) {
        sec <- as.numeric(substr(single,1,nchar(single)-1))
        sec <- sec/60
        sec <- as.numeric(format(round(sec, 3), nsmall = 3))
      }
      if (grepl('\\d+m$', single)) {
        minute <- as.numeric(substr(single,1,nchar(single)-1))
        minute <- as.numeric(format(round(minute, 2), nsmall = 2))
      }
      if (grepl('\\d+h', single)) {
        hours <- as.numeric(substr(single,1,nchar(single)-1))
        hours <- hours*60
        hours <- as.numeric(format(round(hours, 2), nsmall = 2))
      }

      if (grepl('\\d+ms', single)) {
      mili <- as.numeric(substr(single,1,nchar(single)-2))
        if (mili > 0) {
          mili <- (mili/1000)/60
          mili <- as.numeric(format(round(mili, 4), nsmall = 4))
        }
      }
    }
    new_duration <- (hours+minute+sec+mili)
    list_durations <- append(list_durations,new_duration)
  }
  return(list_durations)
}

list_dur <- convert_time(df$duration)
list_realtime <- convert_time(df$realtime)

df$duration_minutes <- list_dur
df$duration_minutes <- as.numeric(df$duration_minutes)

df$realtime_minutes <- list_realtime
df$realtime_minutes <- as.numeric(df$realtime_minutes)

val <- df %>% group_by(name) %>% summarise(moy = mean(duration_minutes), ect = sd(duration_minutes))

workflow <- character(0)
for (x in df$file) {
  full <- sapply(strsplit(x, split = "/"), "[", 2)
  w <- sapply(strsplit(full, split = "_"), "[", 1)
  workflow <- append(workflow,w)
}
df$workflow <- workflow

processes <- character(0)
for (x in df$name) {
  process <- lapply(strsplit(x, split = ":"), tail, n = 1L)  
  processes <- append(processes, as.character(process))
}
df$name <- processes

filenames <- character(0)
for (x in df$file) {
  file_short_name <- sapply(strsplit(x, split = "/"), "[", 2)
  filenames <- append(filenames,file_short_name)
}
df$file <- filenames

important_processes <- c(15, 16, 17, 18, 7, 1, 1, 1, 1, 1, 1, 1, 1,1,1,1,1,9,1,2,5,6,1,1,1,1,1,15,11,1,1,1,1,12,1,1,1,1,1)

categories <- character(0)
for (x in df$name) {
  if (grepl('\\w*_ALIGN\\w*', x) || grepl('\\w*TRIM\\w*', x) || grepl('MERGE_BOWTIE2', x)) {
    categories <- append(categories, "align")
  }
  else if (grepl('\\w*COOLER\\w*', x)) {
    categories <- append(categories, "cooler")
  }
  else if (grepl('\\w*PAIRS\\w*', x)) {
    categories<- append(categories, "pairs")
  }
  else if (grepl('\\w*MATRIX\\w*', x)) {
    categories<- append(categories, "matrix")
  }
  else if (grepl('\\w*FILTER\\w*', x) || grepl('\\w*PICARD\\w*', x) || grepl('\\w*SAMTOOLS\\w*', x)) {
    categories<- append(categories, "filter")
  }
  else if (grepl('\\w*CUTSITE\\w*', x)) {
    categories<- append(categories, "cutsite")
  }
  else if (grepl('\\w*ITERALIGN\\w*', x)) {
    categories<- append(categories, "iteralign")
  }
  else if (grepl('\\w*SAMPLESHEET\\w*', x) || (grepl('BOWTIE2_BUILD', x) || grepl('\\w*GETCHROM\\w*', x) || grepl('\\w*GET_RESTRIC\\w*', x))) {
    categories<- append(categories, "data_prep")
  }
  else {
    categories <- append(categories, "n")
  }
}
# categories
df$categorie <- categories

print(levels(as.factor(df$name)))
ordered_processes <- tibble(levels(as.factor(df$name)))
order <- c(18, 7, 8, 7, 2, 20, 21, 14, 24, 23, 27, 22, 25, 30, 31, 32, 3, 6, 5, 19, 13, 19, 9, 4, 15, 28, 29, 18, 7, 8, 17, 16, 33, 11, 1, 10, 12, 27, 8)
ordered_processes <- ordered_processes %>% add_column(order = order)
ordered_processes <- rename(ordered_processes, name = `levels(as.factor(df$name))`)

df <- left_join(df, ordered_processes, by= c("name" = "name"))



# pdf("process_time.pdf")

ggplot(df, aes(x = name, y = duration_minutes)) +
  geom_point(aes(color = name, shape = name)) +
  scale_shape_manual(values = important_processes) +
  facet_wrap(~ file, ncol = 8) +
  scale_y_continuous(breaks = seq(0, 490, by = 30)) +
  xlab("Processes") +
  ylab("Duration in minutes") +
  theme(axis.text.x=element_blank(), axis.ticks.x=element_blank()) + 
  ggtitle("Duration time of each process")

ggplot(df, aes(x = fct_reorder(name, order), y = realtime_minutes)) +
  geom_point(aes(color = categorie)) +
  scale_shape_manual(values = important_processes) +
  facet_wrap(~ file, ncol = 8) +
  xlab("Processes") +
  ylab("Duration in minutes") +
  theme(axis.text.x=element_blank(), axis.ticks.x=element_blank())+ 
  ggtitle("Real execution time of each process") +
  scale_y_log10()


# dev.off()
