#!/usr/bin/env python

"""
Bridge from nextflow function call to hicstuff's python function for bam2pairs
"""

import os, sys
import argparse
from hicstuff.log import logger
import hicstuff.log as hcl
import hicstuff.io as hio
import hicstuff.digest as hcd
from Bio import SeqIO
import logging
from hicstuff.version import __version__
from hicstuff.pipeline import bam2pairs, generate_log_header

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("-b1", "--bam1")
    parser.add_argument("-b2", "--bam2")
    parser.add_argument("-o", "--out_pairs")
    parser.add_argument("-x", "--out_idx")
    parser.add_argument("-i", "--info_contigs")
    parser.add_argument("-q", "--min_qual")
    parser.add_argument("-e", "--enzyme")
    parser.add_argument("-f", "--fasta")
    parser.add_argument("-c", "--circular")
    args = parser.parse_args()

    bam1 = args.bam1
    bam2 = args.bam2
    out_pairs = args.out_pairs
    out_idx = args.out_idx
    info_contigs = args.info_contigs
    min_qual = int(args.min_qual)
    enzyme = args.enzyme
    fasta = args.fasta
    circular = args.circular

    #hicstuff case sensitive enzymes adaptation
    if enzyme == "hindiii":
        enzyme = "HindIII"
    elif enzyme == "dpnii":
        enzyme = "DpnII"
    elif enzyme == "bglii":
        enzyme = "BglII"
    elif enzyme == "mboi":
        enzyme = "MboI"
    elif enzyme == "arima":
        enzyme = ["DpnII","HinfI"]

    log_file = "hicstuff_pairs.log"
    sys.stderr = open ("hicstuff_pairs.log", "wt")
    hcl.set_file_handler(log_file)
    generate_log_header(log_file, bam1, bam2, fasta, enzyme)

    bam2pairs(bam1, bam2, out_pairs, info_contigs, min_qual)

    restrict_table = {}
    for record in SeqIO.parse(hio.read_compressed(fasta), "fasta"):
        # Get chromosome restriction table
        restrict_table[record.id] = hcd.get_restriction_table(
            record.seq, enzyme, circular=circular
        )

    hcd.attribute_fragments(out_pairs, out_idx, restrict_table)

    hio.sort_pairs(
        out_idx,
        out_idx + ".sorted",
        keys=["chr1", "pos1", "chr2", "pos2"],
        threads=1,
        tmp_dir=None,
    )
    os.rename(out_idx + ".sorted", out_idx)
