#!/usr/bin/env python

import os, sys
import argparse
from hicstuff.log import logger
import hicstuff.log as hcl
import hicstuff.pipeline as hp

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("-p", "--pairs")
    parser.add_argument("-f", "--fragments")
    parser.add_argument("-t", "--type")
    parser.add_argument("-o", "--output")
    args = parser.parse_args()

    pairs = args.pairs
    fragments_list = args.fragments
    mat_fmt = args.type
    mat_out = args.output

    log_file = "hicstuff_matrix.log"
    sys.stderr = open ("hicstuff_matrix.log", "wt")
    hcl.set_file_handler(log_file)

    # Build matrix from pairs.
    if mat_fmt == "cool":

        # Log which pairs file is being used and how many pairs are listed
        pairs_count = 0
        with open(pairs, "r") as file:
            for line in file:
                if line.startswith('#'):
                    continue
                else:
                    pairs_count += 1
        logger.info(
            "Generating matrix from pairs file %s (%d pairs in the file) ",
            pairs, pairs_count
        )

        # Name matrix file in .cool
        mat = os.path.splitext(mat_out)[0] + ".cool"

        hp.pairs2cool(pairs, mat, fragments_list, exclude=None)

    else:
        hp.pairs2matrix(
            pairs,
            mat_out,
            fragments_list,
            mat_fmt=mat_fmt,
            threads=1,
            tmp_dir=None,
        )
