#!/usr/bin/env python3
# -*- coding: utf-8 -*-

"""
Bridge from nextflow function call to hicstuff's python function for distance law
"""

import numpy as np
import argparse
import hicstuff.distance_law as hdl

if __name__ == "__main__":
    parser = argparse.ArgumentParser()
    parser.add_argument("-i", "--input")
    parser.add_argument("-f", "--fragment")
    parser.add_argument("-c", "--centro_file")
    parser.add_argument("-b", "--base")
    parser.add_argument("-p", "--prefix")
    parser.add_argument("-o", "--out_file")
    parser.add_argument("-u", "--circular")
    parser.add_argument("-r", "--rm_centro")
    parser.add_argument("-l", "--plot")
    parser.add_argument("-d", '--dist_plot')
    args = parser.parse_args()

    input = args.input
    fragment = args.fragment
    prefix = args.prefix
    centro_file = args.centro_file
    if centro_file == "None":
        centro_file = None
    else:
        centro_file = prefix+"_"+centro_file
    base = float(args.base)
    out_file = prefix+"_"+args.out_file
    circular = args.circular
    if circular.lower() == "false":
        circular = False
    elif circular.lower() == "true":
        circular = True
    rm_centro = args.rm_centro
    if rm_centro == "None":
        rm_centro = 0
    rm_centro = int(rm_centro)
    plot = args.plot
    if plot.lower() == "false":
        plot = False
    elif plot.lower() == "true":
        plot = True
    distance_law_plot = args.dist_plot
    if distance_law_plot == "None":
        distance_law_plot = None
    else:
        distance_law_plot = prefix+"_"+distance_law_plot

    x_s, p_s, _ = hdl.get_distance_law(
        input,
        fragment,
        centro_file,
        base,
        out_file,
        circular,
        rm_centro
    )

    if plot:
            # Retrieve chrom labels from distance law file
            _, _, chr_labels = hdl.import_distance_law(out_file)
            chr_labels = [lab[0] for lab in chr_labels]
            chr_labels_idx = np.unique(chr_labels, return_index=True)[1]
            chr_labels = [chr_labels[index] for index in sorted(chr_labels_idx)]
            p_s = hdl.normalize_distance_law(x_s, p_s)
            plot_ps_slope(x_s, p_s, labels=chr_labels, fig_path=distance_law_plot)
