process ITERALIGN {
    tag "$meta.id"
    label "process_high"

    container = "docker.io/lbmc/hicstuff:3.2.3"

    input:
    tuple val(meta), path(reads)
    tuple val(meta2), path(index)

    output:
    tuple val(meta), path ("*iteraligned.bam"), emit: bam
    path "versions.yml", emit: versions

    script:
    def prefix = task.ext.prefix ?: "${meta.id}_${meta.mates}"
    def args = task.ext.args ?: ''

    """
    INDEX=`find -L ./ -name "*.rev.1.bt2" | sed "s/\\.rev.1.bt2\$//"`
    [ -z "\$INDEX" ] && INDEX=`find -L ./ -name "*.rev.1.bt2l" | sed "s/\\.rev.1.bt2l\$//"`
    [ -z "\$INDEX" ] && echo "Bowtie2 index files not found" 1>&2 && exit 1

    hicstuff_iteralign.py -r ${reads} -g \$INDEX -b ${prefix}.bam -n ${task.cpus} ${args}

    samtools view -F 2048 -h -@ $task.cpus -O BAM ${prefix}.bam -o ${prefix}_iteraligned.bam

    cat <<-END_VERSIONS > versions.yml
    "${task.process}":
        hicstuff: v3.1.3)
    END_VERSIONS
    """
}
